@@ -62,7 +62,7 @@ void printHeader() {
 #endif
     cout << "                                                       \\...|" << endl;
     cout << "     (C) The Normaliz Team, University of Osnabrueck    \\..|" << endl;
-    cout << "                    February  2024                       \\.|" << endl;
+    cout << "                        May  2024                        \\.|" << endl;
     cout << "                                                          \\|" << endl;
     string optional_packages = package_string();
     if (optional_packages.size() > 0) {
@@ -173,6 +173,8 @@ int main(int argc, char* argv[]){
     ProfilerStart("normaliz.prof");
 #endif
 
+    running_input_file = true; // used to print output files directly
+
     verb_length = 0;
 
     // signal handler for interrupt
@@ -200,7 +202,6 @@ int main(int argc, char* argv[]){
     }
 */
 
-
     string global_command_line = command_line;
 
     // read command line options
@@ -528,9 +529,9 @@ int process_data(OptionsHandler& options, const string& command_line) {
         }
 
         if(options.isUseSaveLocalSolutions()){
-            if(!options.getToCompute().test(ConeProperty::DistributedComp))
-                throw BadInputException("SaveLocalSolutions only allowed with DistributedComp");
             save_local_solutions = true;
+            if(level_local_solutions == -1)
+                throw BadInputException("SaveLocalSolutions requires level set by -Q");
         }
 
         /* if(options.isUseNextRound()){
@@ -561,7 +562,7 @@ int process_data(OptionsHandler& options, const string& command_line) {
         ifstream in;
         in.open(file_in, ifstream::in);
         if (!in.is_open()) {
-            if(options.get_given_name_contains_in()){
+            if(options.get_given_name_contains_in() || is_split_patching){ // patching requires real input file
                 cerr << "error: Failed to open file " << name_in << "." << endl;
                 return 1;
             }
@@ -573,6 +574,10 @@ int process_data(OptionsHandler& options, const string& command_line) {
                 return 1;
             }
         }
+        else{
+            if(options.isUseMakeFullInput())
+                throw BadInputException("MkaeFusionInput not allowed if input file exists");
+        }
 
         string polynomial;
         vector<string> polynomial_equations;
@@ -625,7 +630,7 @@ int process_data(OptionsHandler& options, const string& command_line) {
                 verboseOutput() << "Input file: " << options.getProjectName() << endl;
             verboseOutput() << "Compute: ";
             if (options.getToCompute().none())
-                verboseOutput() << "No computation goal set, using defaults for given input" << endl;
+                verboseOutput() << "No computation goal/variant  set, using defaults for given input" << endl;
             else
                 verboseOutput() << options.getToCompute() << endl;
             for(auto& P: num_param_input)
@@ -697,3 +702,30 @@ int process_data(OptionsHandler& options, const string& command_line) {
     return 0;
 }
 
+    /*
+    verbose = true;
+    vector<mpq_class> ty = {1,1,2,2};
+    vector<mpq_class> du = {-1,1,2,3};
+    Matrix<mpq_class> ty_mat(0,4);
+    ty_mat.append(ty);
+    Matrix<mpq_class> du_mat(0,4);
+    du_mat.append(du);
+    Cone<long long> CT(Type::fusion_type, ty_mat, Type::fusion_duality, du_mat);
+    // CT.compute(ConeProperty::FusionRings, ConeProperty::UseModularGrading);
+    Matrix<long long> Res = CT.getFusionRingsMatrix();
+    Res.debug_print();
+    CT.compute(ConeProperty::FusionRings, ConeProperty::UseModularGrading);
+    Res = CT.getFusionRingsMatrix();
+    Res.debug_print();
+    Res = CT.getSingleFusionRing();
+    exit(0);
+    Res.debug_print('%');
+    CT.compute(ConeProperty::FusionRings, ConeProperty::UseModularGrading);
+    Res = CT.getFusionRingsMatrix();
+    Res.debug_print('@');
+    CT.setModularGraing(0);
+    cout << "-------------------------------------------------------------------------------------------------------" << endl;
+    Res = CT.getFusionRingsMatrix();
+    Res.debug_print();
+    exit(0); */
+
